dnl Try to find the libqt and set ac_qt_includes and ac_qt_libraries
dnl ac_qt_includes and ac_qt_libraries will be set correctly.

AC_DEFUN(AC_FIND_LIBQT, [
ac_qt_includes=NO
ac_qt_libraries=NO
ac_qt_moc=NO
AC_SUBST(ac_qt_includes)
AC_SUBST(ac_qt_libraries)
AC_SUBST(ac_qt_moc)

AC_ARG_WITH(qt-dir,
	[  --with-qt-dir           where the root of qt is installed ],
	[
		ac_try_qt_includes="$withval"/include
		ac_try_qt_libraries="$withval"/lib
	])
AC_ARG_WITH(qt-includes,
	[  --with-qt-includes      where the qt includes are.],
	[ ac_try_qt_includes="$withval" ])
AC_ARG_WITH(qt-libraries,
	[  --with-qt-libraries     where the qt library is installed.],
	[ ac_try_qt_libraries="$withval" ])
AC_ARG_WITH(qt-moc,
	[  --with-qt-moc           where the qt meta object compiler is],
	[ ac_try_qt_moc="$withval" ])

AC_MSG_CHECKING([Searching for libQT header files])
AC_FIND_LIBQT_FILE(qpainter.h, "$ac_try_qt_includes" /usr/lib/qt/include /usr/local/qt/include /usr/include/qt /usr/include /usr/X11R6/include/X11/qt, ac_qt_includes)
if test "$ac_qt_includes" = "NO"; then
  AC_MSG_RESULT([not found])
  AC_MSG_ERROR([libQT header files must be installed. consider ./configure --help for libQT options])
fi
AC_MSG_RESULT($ac_qt_includes)

AC_MSG_CHECKING([Searching for libQT library files])
AC_FIND_LIBQT_FILE(libqt.a "libqt.so*", "$ac_try_qt_libraries" /usr/lib/qt/lib /usr/X11R6/lib /usr/lib /usr/local/qt/lib /usr/lib/qt, ac_qt_libraries)
if test "$ac_qt_libraries" = "NO"; then
  AC_MSG_RESULT([not found])
  AC_MSG_ERROR([libQT library files must be installed. consider ./configure --help for libQT options])
fi
AC_MSG_RESULT($ac_qt_libraries)

AC_PATH_PROG(ac_qt_moc, moc)
if test -x "$ac_qt_moc"; then
  true
else
  AC_MSG_ERROR([libQT meta object compiler must be installed and in search PATH])
fi

AC_MSG_CHECKING([Trying to compile complete simple libQT program])
cat > conftest.cpp << EOF
#include <qpainter.h>
int main () {return 0;};
EOF
ac_compile='${CXX} -c $CXXFLAGS -I$ac_qt_includes conftest.cpp -o conftest.o'
if AC_TRY_EVAL(ac_compile); then
  true
else
  rm -f conftest*
  AC_MSG_RESULT([error])
  AC_MSG_ERROR([hmmm. why did THIS happen ?])
fi
AC_MSG_RESULT([ok])
AC_MSG_CHECKING([Trying to link complete simple libQT program])
ac_link='${CXX} $LDFLAGS -L$ac_qt_libraries conftest.o -o conftest -lqt'
if AC_TRY_EVAL(ac_link); then
  true
else
  rm -f conftest*
  AC_MSG_RESULT([error])
  AC_MSG_ERROR([hmmm. why did THIS happen ?])
fi
AC_MSG_RESULT([ok])
rm -f conftest*

])

# find multiple files in multiple directories.
# $1 list of files (wildcards allowed)
# $2 list of directories
# $3 first directory that contained any of the files or NO if error
AC_DEFUN(AC_FIND_LIBQT_FILE,[
$3=NO
for i in $2; do
  for j in $1; do
    for k in "$i/"$j; do
      if test -r "$k" && test -f "$k"; then
        $3=$i
        break 3
      fi
    done
  done
done
])
